#[non_exhaustive]pub enum VeraError {
AuthenticationFailed,
TooSmall {
got: usize,
},
Crypto {
what: &'static str,
},
Io(Error),
}Expand description
A VeraCrypt parse or unlock failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AuthenticationFailed
No PRF/cipher combination decrypted the header to a valid VERA signature
with matching CRCs — a wrong password, an unsupported cipher/PRF, or not a
VeraCrypt volume.
TooSmall
The container is too small to hold a VeraCrypt header.
Crypto
A cryptographic precondition failed.
Io(Error)
An I/O error reading the container.